#!/usr/bin/env bash

# Stop script if a command fails
set -e
set -o pipefail

SCRIPT_PATH=`dirname "${0}"`

if [ -z "${HOME}" ]; then
    echo "Error: Cannot install: User home directory not set in environment variable HOME!"
    exit 1
fi

if [ -z "${XDG_DATA_HOME}" ]; then
    XDG_DATA_HOME="${HOME}/.local/share"
fi

XDG_APPS_PATH="${XDG_DATA_HOME}/applications"
BIN_PATH="${HOME}/bin"

mkdir -p "${XDG_APPS_PATH}"
mkdir -p "${BIN_PATH}"

WRC_PROXY_EXECUTABLE="${BIN_PATH}/wrc-proxy"
WRC_PROXY_URI_HANDLER="${XDG_APPS_PATH}/wrc-proxy.desktop"

echo "Installing wrc-proxy binary to ${WRC_PROXY_EXECUTABLE} ..."

cp -af "${SCRIPT_PATH}/wrc-proxy" "${WRC_PROXY_EXECUTABLE}"
chmod a+x "${WRC_PROXY_EXECUTABLE}"

echo "Installing wrc-proxy: URI handler for web browsers to ${WRC_PROXY_URI_HANDLER} ..."

cat <<EOF >"${WRC_PROXY_URI_HANDLER}"
[Desktop Entry]
Encoding=UTF-8
Version=1.0
Type=Application
Terminal=true
Exec=${WRC_PROXY_EXECUTABLE} -n -i -p 4532 -u %u
Name=wrc-proxy
Comment=Web Radio Control proxy for remote control via external applications
Icon=
Categories=Application;Network;
MimeType=x-scheme-handler/wrc-proxy;
EOF

xdg-mime default wrc-proxy.desktop x-scheme-handler/wrc-proxy

echo "Installation complete!"

read -p "Press ENTER to close this installer." -n1
